==> visualvm_2.0.6+dfsg.orig.tar.gz: visualvm-2.0.6/visualvm/host/src/org/graalvm/visualvm/host/impl/HostProperties.java <==
/*
 * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.host.impl;

import org.graalvm.visualvm.core.properties.PropertiesCustomizer;

/**
 *
 * @author Jiri Sedlacek
 */
public class HostProperties {

    private final String hostName;
    private final String displayName;
    private final PropertiesCustomizer customizer;


    public HostProperties(String hostName, String displayName,
                          PropertiesCustomizer customizer) {
        this.customizer = customizer;
        this.hostName = hostName;
        this.displayName = displayName;
    }


    public String getHostName() { return hostName; }

    public String getDisplayName() { return displayName; }

    public PropertiesCustomizer getPropertiesCustomizer() { return customizer; }

}

==> visualvm-2.2.tar.gz: visualvm-2.2/visualvm/host/src/org/graalvm/visualvm/host/impl/HostProperties.java <==
/*
 * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.host.impl;

import org.graalvm.visualvm.core.properties.PropertiesCustomizer;
import org.graalvm.visualvm.host.Host;

/**
 *
 * @author Jiri Sedlacek
 */
public class HostProperties {

    private final String hostName;
    private final String displayName;
    private final PropertiesCustomizer<Host> customizer;


    public HostProperties(String hostName, String displayName,
                          PropertiesCustomizer<Host> customizer) {
        this.customizer = customizer;
        this.hostName = hostName;
        this.displayName = displayName;
    }


    public String getHostName() { return hostName; }

    public String getDisplayName() { return displayName; }

    public PropertiesCustomizer<Host> getPropertiesCustomizer() { return customizer; }

}
